@@ -44,6 +44,10 @@ class Aug(object):
         if not self._enabled:
             return
 
+        if output.is_user_messages_queue_full():
+            logger.warn("Skipping aug ({}) execution because the queue is full".format(self.aug_id))
+            return
+
         now = time.time()
         limit_key = None
         executed = False
