@@ -47,12 +47,6 @@ class AugFactory(Factory):
         except KeyError as exc:
             six.raise_from(RookAugInvalidKey('id', json.dumps(configuration)), exc)
 
-        try:
-            locationDict = configuration['location']
-        except KeyError as exc:
-            six.raise_from(RookAugInvalidKey('location', json.dumps(configuration)), exc)
-        location = self._get_dynamic_class(locationDict)
-
         if 'extractor' in configuration:
             extractor = self._get_dynamic_class(configuration['extractor'])
         else:
@@ -83,15 +77,21 @@ class AugFactory(Factory):
 
         max_aug_execution_time = AugFactory.get_dict_value(configuration, 'maxAugTime', config.InstrumentationConfig.MAX_AUG_TIME)
 
-        return Aug(aug_id=aug_id,
-                   location=location,
+        aug = Aug(aug_id=aug_id,
                    extractor=extractor,
                    condition=condition,
                    action=action,
-                   output=self._output,
                    max_aug_execution_time=max_aug_execution_time,
                    rate_limits=rate_limits)
 
+        try:
+            locationDict = configuration['location']
+        except KeyError as exc:
+            six.raise_from(RookAugInvalidKey('location', json.dumps(configuration)), exc)
+        location = self._get_location(aug, locationDict)
+
+        return location
+
     def _load_dynamic_classes(self):
         """Load all dynamic classes into the factory."""
         self.register_methods(locations.__all__)
@@ -100,24 +100,43 @@ class AugFactory(Factory):
         self.register_methods(actions.__all__)
 
     def _get_dynamic_class(self, configuration):
-        """Return a class based on configuration."""
+        """Return a class instance based on configuration."""
 
         if not configuration:
             return None
         else:
-            try:
-                name = configuration['name']
-            except KeyError as exc:
-                six.raise_from(RookObjectNameMissing(json.dumps(configuration)), exc)
-
-            try:
-                factory = self.get_object_factory(name)
-            except (RookUnknownObject, AttributeError, KeyError) as exc:
-                six.raise_from(RookUnsupportedLocation(name), exc)
+            factory = self._get_factory(configuration)
 
             try:
                 return factory(configuration, self._processor_factory)
             except ToolException:
                 raise
             except Exception as exc:
-                six.raise_from(RookInvalidObjectConfiguration(name, json.dumps(configuration)), exc)
+                six.raise_from(RookInvalidObjectConfiguration(configuration['name'], json.dumps(configuration)), exc)
+
+    def _get_location(self, aug, configuration):
+        """Return a location instance based on configuration."""
+
+        if not configuration:
+            return None
+        else:
+            factory = self._get_factory(configuration)
+
+            try:
+                return factory(self._output, aug, configuration, self._processor_factory)
+            except ToolException:
+                raise
+            except Exception as exc:
+                six.raise_from(RookInvalidObjectConfiguration(configuration['name'], json.dumps(configuration)), exc)
+
+    def _get_factory(self, configuration):
+        """Return a class factory on configuration."""
+        try:
+            name = configuration['name']
+        except KeyError as exc:
+            six.raise_from(RookObjectNameMissing(json.dumps(configuration)), exc)
+
+        try:
+            return self.get_object_factory(name)
+        except (RookUnknownObject, AttributeError, KeyError) as exc:
+            six.raise_from(RookUnsupportedLocation(name), exc)
