@@ -13,10 +13,20 @@ from rook.logger import logger
 
 
 class Information(object):
+
+    # Default location of the Kubernetes namespace file
+    _k8sNamespaceFileName_default = "/var/run/secrets/kubernetes.io/serviceaccount/namespace"
+    _k8sNamespaceFileName = _k8sNamespaceFileName_default
+
     def __init__(self):
         self.debug = False
 
-    def collect(self, debug=False):
+    def collect(self, debug=False, k8namespaceFile=None):
+
+        # Override the default Kuberates namespace filename, use for debug
+        if k8namespaceFile:
+            self._k8sNamespaceFileName = k8namespaceFile
+
         for name, collector in six.iteritems(self._collectors):
             try:
                 if callable(collector):
@@ -43,7 +53,8 @@ class SCMInformation(Information):
         }
 
     def _get_commit(self):
-        user_commit = GitConfig.GIT_COMMIT or os.environ.get('ROOKOUT_COMMIT', '')
+        user_commit = GitConfig.GIT_COMMIT or os.environ.get(
+            'ROOKOUT_COMMIT', '')
 
         if user_commit:
             return user_commit
@@ -56,7 +67,8 @@ class SCMInformation(Information):
         return ''
 
     def _get_origin(self):
-        user_remote_origin = GitConfig.GIT_ORIGIN or os.environ.get('ROOKOUT_REMOTE_ORIGIN', '')
+        user_remote_origin = GitConfig.GIT_ORIGIN or os.environ.get(
+            'ROOKOUT_REMOTE_ORIGIN', '')
 
         if user_remote_origin:
             return user_remote_origin
@@ -133,23 +145,57 @@ class PlatformInformation(Information):
         }
 
 
+class ClusterInformation(Information):
+
+    def __init__(self):
+        super(ClusterInformation, self).__init__()
+        self._collectors = {
+            'k8s_namespace': self._get_namespace_name
+        }
+
+    def _get_namespace_name(self):
+        """
+        Collect Kubernates cluster information
+        """
+        filename = self._k8sNamespaceFileName
+        try:
+            if not os.path.isfile(filename):
+                # Not running on a Kubernates cluster is valid
+                return ''
+        except:  # lgtm[py/catch-base-exception]
+            return ''
+
+        try:
+            with open(filename, 'r') as f:
+                contents = f.read()
+        except:  # lgtm[py/catch-base-exception]
+            logger.debug(
+                "Failed to read Kubernates information from: %s", filename)
+            return ''
+
+        return contents
+
+
 class AgentInformation(Information):
     def __init__(self):
         super(AgentInformation, self).__init__()
+
         self._collectors = {
             'version': lambda: VersionInformation().collect(),
             'network': lambda: NetworkInformation().collect(),
             'system': lambda: SystemInformation().collect(),
             'platform': lambda: PlatformInformation().collect(),
             'scm': lambda: SCMInformation().collect(),
+            'cluster': lambda: ClusterInformation().collect(
+                k8namespaceFile=self._k8sNamespaceFileName),
             'executable': lambda: sys.argv[0],
             'command_arguments': lambda: sys.argv[1:],
             'process_id': os.getpid
         }
 
 
-def collect(debug):
-    return AgentInformation().collect(debug)
+def collect(debug, k8namespaceFile=None):
+    return AgentInformation().collect(debug, k8namespaceFile)
 
 
 def pack_agent_info(info):
@@ -191,6 +237,9 @@ def pack_agent_info(info):
     if info.debug:
         packed_info.labels["rookout_debug"] = "on"
 
+    if info.cluster and info.cluster.k8s_namespace != '':
+        packed_info.labels["k8s_namespace"] = info.cluster.k8s_namespace
+
     packed_info.tags.extend(info.tags)
 
     return packed_info
