@@ -132,6 +132,9 @@ class AgentCom(object):
         self._queue.put(packaged_message)
         return None
 
+    def is_queue_full(self):
+        return self._queue.qsize() >= AgentComConfiguration.MAX_QUEUED_MESSAGES
+
     def on(self, message_name, callback):
         self._register_callback(message_name, MessageCallback(callback, True))
 
