@@ -126,3 +126,6 @@ class Output(object):
         new_err.exc.CopyFrom(e.exc)
         new_err.traceback.CopyFrom(e.traceback)
         return new_err
+
+    def is_user_messages_queue_full(self):
+        return self._user_message_bucket.is_exhausted() or (self._agent_com is not None and self._agent_com.is_queue_full())
