@@ -10,6 +10,8 @@ import inspect
 from ..processor.namespaces.python_object_namespace import PythonObjectNamespace
 
 from rook.config import LoggingConfiguration
+from rook.serverless import on_lambda
+from rook.config import LoggingConfiguration, ShutdownConfig
 
 LOG_LEVELS = ["trace", "debug", "info", "warning", "error", "fatal"]
 
@@ -116,6 +118,9 @@ class Logger(object):
 
     def _log(self, level, message, args, **kwargs):
         try:
+            if ShutdownConfig.IS_SHUTTING_DOWN:
+                return
+
             level_no = len(LOG_LEVELS)
             try:
                 level_no = LOG_LEVELS.index(level)
@@ -139,8 +144,7 @@ class Logger(object):
                 handler(record)
 
         except Exception:
-            six.print_("[Rookout] Unexpected error when writing to log:")
-            traceback.print_exc()
+            six.print_("[Rookout] Unexpected error when writing to log: " + traceback.format_exc())
 
     def _build_handlers(self):
         handlers = []
@@ -148,9 +152,10 @@ class Logger(object):
         if LoggingConfiguration.LOG_TO_STDERR:
             handlers.append(self._get_stderr_handler())
 
-        file_handler = self._get_file_handler(LoggingConfiguration.FILE_NAME)
-        if file_handler:
-            handlers.append(file_handler)
+        if not on_lambda():
+            file_handler = self._get_file_handler(LoggingConfiguration.FILE_NAME)
+            if file_handler:
+                handlers.append(file_handler)
 
         handlers.append(self._remote_handler)
 
