@@ -11,6 +11,7 @@ from google.protobuf.internal.type_checkers import Int32ValueChecker, Int64Value
 from .namespaces.container_namespace import ContainerNamespace
 from .namespaces.python_object_namespace import PythonObjectNamespace
 from .namespaces.collection_namespace import DictNamespace, ListNamespace, LIST_TYPE
+from .namespaces.traceback_namespace import TracebackNamespace
 from .namespaces.user_object_namespace import UserObjectNamespace
 from .namespaces.error_namespace import ErrorNamespace
 from .namespaces.max_depth_namespace import MaxDepthNamespace
@@ -72,6 +73,8 @@ class NamespaceSerializer(object):
                 self._dump_formatted_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, UnknownNamespace):
                 self._dump_unknown_namespace(namespace, variant, log_errors)
+            elif isinstance(namespace, TracebackNamespace):
+                self._dump_traceback_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, CodeObjectNamespace):
                 self.dump_code_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, DynamicObjectNamespace):
@@ -456,6 +459,9 @@ class NamespaceSerializer(object):
     def _dump_max_depth_namespace(self, namespace, variant, log_errors):
         variant.variant_type = variant.VARIANT_MAX_DEPTH
 
+    def _dump_traceback_namespace(self, namespace, variant, log_errors):
+        namespace.dump(variant)
+
     def dump_code_namespace(self, namespace, variant, log_errors):
         self._dump_dumped_object_namespace(namespace, variant, log_errors)
 
