@@ -9,13 +9,10 @@ from .python_object_namespace import PythonObjectNamespace
 from rook.exceptions import RookAttributeNotFound, RookInvalidMethodArguments
 
 
-from six import string_types
-
 # Fixing a bug in PyPy
 import platform
 if 'PyPy' == platform.python_implementation():
     import sys
-    import six
     FakeFrameType = type(next(six.itervalues(sys._current_frames())))
     from types import FrameType
 
@@ -75,7 +72,7 @@ class FrameNamespace(Namespace):
             try:
                 depth = int(args)
             except ValueError:
-                if isinstance(args, string_types):
+                if isinstance(args, six.string_types):
                     try:
                         dump_config = PythonObjectNamespace.dump_configs[args.lower()]
                     except KeyError:
