@@ -74,14 +74,21 @@ class TraceNamespace(Namespace):
                 try_generic_opentrace = False
 
         except ImportError:
-            pass
+            pass # We'll try the generic opentrace next
 
         if try_generic_opentrace:
             try:
                 import opentracing
                 self.span = opentracing.tracer.active_span
             except ImportError:
-                return False
+                pass
+
+            if not self.span:
+                try:
+                    from opentelemetry import trace
+                    self.span = trace.get_current_span()
+                except ImportError:
+                    return False
 
         if self.span:
             return True
@@ -92,7 +99,7 @@ class TraceNamespace(Namespace):
         try:
             import jaeger_client
             return isinstance(span, jaeger_client.span.Span)
-        except:
+        except Exception:
             pass
         return False
 
